# This file will be patched by setup.py
# The __version__ should be set to the branch name
# (e.g. "develop" or "1.2.x")

# You MUST use double quotes (so " and not ')

__version__ = "1.1.1"
__baseline__ = "33a7874416d8a8cc6a0d1e3f8d1e4042f2762d81"
